﻿using UnityEngine;
using UnityEngine.Events;

namespace AudioMate
{
    public abstract class Screen : MonoBehaviour
    {
        public class ScreenChangeRequestedEvent : UnityEvent<string> { }

        public static readonly ScreenDefinition Definition = new ScreenDefinition(
            "",
            "",
            typeof(Screen));

        public string GetID => Definition.ID;
        public string GetTitle => Definition.Title;

        public readonly ScreenChangeRequestedEvent OnScreenChangeRequested = new ScreenChangeRequestedEvent();

        protected AudioMateController _c;
        protected UIFactory _ui;
        private bool _disposing;

        public virtual void Init(AudioMateController controller)
        {
            _c = controller;
            _ui = gameObject.AddComponent<UIFactory>();
            _ui.c = controller;
            _c.collections.OnActiveCollectionSelected.AddListener(OnActiveCollectionSelected);
            _c.collections.OnActiveCollectionUpdated.AddListener(OnActiveCollectionUpdated);
            _c.collections.OnActiveCollectionNameChanged.AddListener(OnActiveCollectionNameChanged);
            _Init();
        }

        public virtual void _Init()
        {
            // ...
        }

        protected virtual void OnActiveCollectionSelected(CollectionManager.ActiveCollectionSelectedEventArgs args)
        {
            // ...
        }

        protected virtual void OnActiveCollectionUpdated()
        {
            // ...
        }

        protected virtual void OnActiveCollectionNameChanged(CollectionManager.ActiveCollectionNameChangedEventArgs args)
        {
            // ...
        }

        public virtual void OnDestroy()
        {
            if (_disposing) return;
            _disposing = true;
            Unbind();
        }

        public virtual void Unbind()
        {
            _c.collections.OnActiveCollectionSelected.RemoveListener(OnActiveCollectionSelected);
            _c.collections.OnActiveCollectionUpdated.RemoveListener(OnActiveCollectionUpdated);
            _c.collections.OnActiveCollectionNameChanged.RemoveListener(OnActiveCollectionNameChanged);
        }

        public virtual void Refresh()
        {
            Unbind();
            Destroy(_ui);
            Init(_c);
        }

        protected virtual void Log(string message)
        {
            if (_c == null) return;
            _c.Log($" [{nameof(Screen)}]: {message}");
        }
    }
}
