using System.Collections.Generic;
using UnityEngine;
using UnityEngine.Events;
using UnityEngine.UI;

namespace AudioMate
{
    public class HorizontalButtonGroup : MonoBehaviour
    {

        private readonly List<UIDynamicButton> _buttons;
        private GameObject _container;
        private HorizontalLayoutGroup _gridLayout;

        public RectOffset Padding
        {
            set { _gridLayout.padding = value; }
        }

        public HorizontalButtonGroup()
        {
            _buttons = new List<UIDynamicButton>();
            Init();
        }

        public void Init()
        {
            _container = new GameObject($"HorizontalButtonGroup{Tools.GenerateID()}");
            _container.transform.SetParent(transform, false);
            _gridLayout = _container.AddComponent<HorizontalLayoutGroup>();
            _gridLayout.spacing = 10f;
            _gridLayout.childForceExpandWidth = false;
            _gridLayout.childForceExpandHeight = false;
            _gridLayout.childControlWidth = true;
            _gridLayout.childControlHeight = true;
            _gridLayout.childAlignment = TextAnchor.MiddleCenter;
        }

        public UIDynamicButton CreateButton(string label, int style = Styles.Button, UnityAction call = null,
            bool addOutline = false, float preferredWidth = 0, float flexibleWidth = 1, int fontSize = 30)
        {
            var instance = Instantiate(UIFactory.ButtonPrefab, transform, false);
            instance.transform.SetParent(_container.transform, false);

            var btn = instance.GetComponent<UIDynamicButton>();
            btn.label = label;
            btn.textColor = Styles.Text(style);
            btn.buttonColor = Styles.Bg(style);
            btn.buttonText.fontSize = fontSize;
            if (call != null) btn.button.onClick.AddListener(call);
            if (addOutline)
            {
                var outline = btn.button.gameObject.AddComponent<Outline>();
                outline.effectColor = Styles.Text(style);
                outline.effectDistance = new Vector2(3f, 3f);
            }
            var layout = instance.GetComponent<LayoutElement>();
            layout.preferredWidth = preferredWidth;
            layout.flexibleWidth = flexibleWidth;
            layout.flexibleHeight = 1;
            _buttons.Add(btn);
            return btn;
        }

        public Text CreateLabel(string text, int style = Styles.Button, bool invertStyle = true, int size = 32, bool bold = true, TextAnchor alignment = TextAnchor.MiddleCenter, float minWidth = 80f)
        {
            var go = new GameObject("Label");
            go.transform.SetParent(_container.transform, false);
            var layout = go.AddComponent<LayoutElement>();
            layout.flexibleWidth = 1f;
            layout.flexibleHeight = 40f;
            layout.preferredWidth = 1f;
            layout.preferredHeight = 20f;
            layout.minWidth = minWidth;

            var label = go.gameObject.AddComponent<Text>();
            label.text = text;
            label.color = invertStyle ? Styles.Bg(style) : Styles.Text(style);
            label.font = UIFactory.BaseFont;
            label.fontSize = size;
            label.fontStyle = bold ? FontStyle.Bold : FontStyle.Normal;
            label.verticalOverflow = VerticalWrapMode.Overflow;
            label.alignment = alignment;

            return label;
        }

        public void Destroy()
        {
            Destroy(_container);
        }

        public UIDynamicButton GetButtonAt(int index)
        {
            return _buttons[index];
        }
    }
}
