﻿using System.Collections.Generic;
using UnityEngine;
using UnityEngine.Events;
using UnityEngine.UI;

namespace AudioMate
{
    public class Tabs : MonoBehaviour
    {
        public static Tabs AddTo(Transform parent)
        {
            var go = new GameObject();
            go.transform.SetParent(parent, false);
            var layout = go.AddComponent<HorizontalLayoutGroup>();
            layout.childForceExpandWidth = true;
            layout.childForceExpandHeight = false;
            layout.childControlWidth = true;
            layout.childControlHeight = true;
            var image = go.AddComponent<Image>();
            image.preserveAspect = false;
            image.color = Styles.EmbeddedBg;
            var btnGroup = go.AddComponent<HorizontalButtonGroup>();
            btnGroup.Padding = new RectOffset(0, 0, 10, 25);
            var tabs = go.AddComponent<Tabs>();
            tabs._buttons = btnGroup;
            return tabs;
        }

        public class TabSelectedEvent : UnityEvent<string> { }
        public readonly TabSelectedEvent OnTabSelected = new TabSelectedEvent();

        private HorizontalButtonGroup _buttons;
        private readonly List<UIDynamicButton> _tabs = new List<UIDynamicButton>();

        public UIDynamicButton Add(string target, string label)
        {
            if (_buttons == null) return null;
            var tabButton = _buttons.CreateButton($"{label.ToUpper()}", Styles.Tab, () =>
            {
                OnTabSelected.Invoke(target);
            }, false, 0f, 1f, 28);
            tabButton.name = target;
            _tabs.Add(tabButton);
            return tabButton;
        }

        public void Select(string target)
        {
            foreach (var tab in _tabs)
            {
                var isActive = tab.name == target;
                tab.button.interactable = !isActive;
                tab.buttonColor = isActive ? Styles.TabActiveBg : Styles.TabBg;
                tab.textColor = isActive ? Styles.TabActiveText : Styles.TabText;
            }
        }
    }
}
