﻿namespace AudioMate
{
    public class ScreenClips : Screen
    {
        public new static readonly ScreenDefinition Definition = new ScreenDefinition(
            "Clips",
            "Clip Library",
            typeof(ScreenClips));

        private HorizontalButtonGroup _btnGroupAddClips;
        private UIClipLibrary _clipLibrary;
        private UIDynamicButton _btnFilter;
        private bool _isFilterOn;

        public override void Init(AudioMateController controller)
        {
            base.Init(controller);
            _ui.CreateSpacer().height = 15f;
            InitAddToCollectionControlsUI();
            CreateClipLibraryUI();
            InitFileImportUI();
        }

        private void InitFileImportUI()
        {
            var btnGroupImport = _ui.CreateButtonGroup();
            btnGroupImport.CreateButton("Import File", Styles.Button, _c.fileManager.OpenImportFileDialog);
            btnGroupImport.CreateButton("Import Folder", Styles.Button, _c.fileManager.OpenImportFolderDialog);

            var btnGroupRemove = _ui.CreateButtonGroup();
            _btnFilter = btnGroupRemove.CreateButton("Hide Unused", _isFilterOn ? Styles.Success : Styles.Button, () =>
            {
                _isFilterOn = !_isFilterOn;
                _clipLibrary.SetFilter(_isFilterOn);
                _btnFilter.buttonColor = _isFilterOn ? Styles.EnabledBg : Styles.ButtonBg;
            });

            btnGroupRemove.CreateButton($"{Symbols.Remove} Unused", Styles.Danger, () =>
            {
                var template = new OverlayTemplates { YesNo = { Callback = () =>
                    _c.clipLibrary.RemoveUnusedClips()
                }};
                _c.ui.container.CreateOverlay("This operation removes all clips from the scene that are not assigned to a collection. Are you sure?", template.YesNo);
            });

            btnGroupRemove.CreateButton($"{Symbols.Remove} All", Styles.Danger, () =>
            {
                var template = new OverlayTemplates { YesNo = { Callback = () =>
                    {
                        _c.collections.ClearAllCollections();
                        _c.clipLibrary.RemoveAllClips();
                    }
                }};
                _c.ui.container.CreateOverlay("This operation removes all clips from the scene and empties all of your collections. Are you sure?", template.YesNo);
            });

        }

        private void CreateClipLibraryUI()
        {
            _clipLibrary = UIClipLibrary.AddTo(_ui.transform);
            _clipLibrary.Init(_c);
            _clipLibrary.Bind();
            _clipLibrary.RefreshAll();
        }


        private void InitAddToCollectionControlsUI()
        {
            _btnGroupAddClips = _ui.CreateButtonGroup();
            _btnGroupAddClips.CreateLabel("Select");
            _btnGroupAddClips.CreateButton("10", Styles.Button, _c.collections.Add10ClipsToActiveCollection);
            _btnGroupAddClips.CreateButton("20", Styles.Button, _c.collections.Add20ClipsToActiveCollection);
            _btnGroupAddClips.CreateButton("All", Styles.Button, _c.collections.AddAllClipsToActiveCollection);
            // _btnGroupAddClips.CreateLabel("\u02C3");
        }
    }
}
