﻿using System.Collections.Generic;
using System.Linq;
using SimpleJSON;

namespace AudioMate
{
    public class ScreenSettings : Screen
    {
        public new static readonly ScreenDefinition Definition = new ScreenDefinition(
            "Settings",
            "Global",
            typeof(ScreenSettings));

        private JSONStorableBool _toggleDisplayHints;
        private JSONStorableBool _toggleVolumeControlEnabled;
        private JSONStorableBool _togglePitchControlEnabled;

        /* private JSONStorableBool _toggleAutoJawMovement;
        private JSONStorableFloat _sliderJawMovementStrength;
        private JSONStorableFloat _sliderJawHoldSpring;
        private JSONStorableFloat _sliderJawHoldDamper;
        private JSONStorableFloat _sliderJawAdditionalAngle;
        private JSONStorableFloat _sliderJawMaxAngle; */

        public override void Init(AudioMateController controller)
        {
            base.Init(controller);
            InitSettingsUI();
        }

        private void InitSettingsUI()
        {
            _ui.CreateHeader("Global Settings", 2);
            _toggleDisplayHints = new JSONStorableBool(
                "Display Hints",
                _c.DisplayHintsJSON.val,
                val => _c.DisplayHintsJSON.val = val);
            _ui.CreateToggle(_toggleDisplayHints);
            _toggleVolumeControlEnabled = new JSONStorableBool(
                "Enable Volume Control",
                _c.VolumeControlEnabledJSON.val,
                val => _c.VolumeControlEnabledJSON.val = val);
            _ui.CreateToggle(_toggleVolumeControlEnabled);
            _togglePitchControlEnabled = new JSONStorableBool(
                "Enable Pitch Control",
                _c.PitchControlEnabledJSON.val,
                val => _c.PitchControlEnabledJSON.val = val);
            _ui.CreateToggle(_togglePitchControlEnabled);
            /*
            _ui.CreateHeader("Auto Expressions [BETA]", 2);

            _toggleAutoJawMovement = new JSONStorableBool(
                "Enable Auto Jaw Movement",
                _c.jawControl.GetBoolParamValue("driveXRotationFromAudioSource"),
                val => _c.jawControl.SetBoolParamValue("driveXRotationFromAudioSource", val));
            _ui.CreateToggle(_toggleAutoJawMovement);

            _sliderJawMovementStrength = new JSONStorableFloat(
                "Jaw Movement Strength",
                _c.jawControl.GetFloatParamValue("driveXRotationFromAudioSourceMultiplier"),
                val => _c.jawControl.SetFloatParamValue("driveXRotationFromAudioSourceMultiplier", val),
                0f,
                1000f);
            _ui.CreateSlider(_sliderJawMovementStrength, 1f, true);

            _sliderJawHoldSpring = new JSONStorableFloat(
                "Jaw Hold Spring",
                _c.jawControl.GetFloatParamValue("spring"),
                val => _c.jawControl.SetFloatParamValue("spring", val),
                0f,
                100f);
            _ui.CreateSlider(_sliderJawHoldSpring, 1f, true);

            _sliderJawHoldDamper = new JSONStorableFloat(
                "Jaw Hold Damper",
                _c.jawControl.GetFloatParamValue("damper"),
                val => _c.jawControl.SetFloatParamValue("damper", val),
                0f,
                5f);
            _ui.CreateSlider(_sliderJawHoldDamper, 1f, true);

            _sliderJawAdditionalAngle = new JSONStorableFloat(
                "Jaw Additional Angle",
                _c.jawControl.GetFloatParamValue("driveXRotationFromAudioSourceAdditionalAngle"),
                val => _c.jawControl.SetFloatParamValue("driveXRotationFromAudioSourceAdditionalAngle", val),
                -35,
                0f);
            _ui.CreateSlider(_sliderJawAdditionalAngle, 1f, true);

            _sliderJawMaxAngle = new JSONStorableFloat(
                "Jaw Max. Angle",
                _c.jawControl.GetFloatParamValue("driveXRotationFromAudioSourceMaxAngle"),
                val => _c.jawControl.SetFloatParamValue("driveXRotationFromAudioSourceMaxAngle", val),
                -35f,
                0f);
            _ui.CreateSlider(_sliderJawMaxAngle, 1f, true); */
        }
    }
}
